@@ -32,7 +32,7 @@
 
 #include <fwTools/Type.hpp>
 
-fwCampAutoDeclareDataMacro((fwData)(Array), FWDATA_API);
+fwCampAutoDeclareDataMacro((fwData)(Array));
 
 namespace fwData
 {
@@ -371,6 +371,7 @@ public:
         /// @}
 
         /// Constructor
+        IteratorBase();
         IteratorBase(ArrayType array);
         /// Copy constructor
         IteratorBase(const IteratorBase<TYPE, false>& other);
@@ -410,7 +411,7 @@ public:
         ::fwMemory::BufferObject::Lock m_lock;
         pointer m_pointer{nullptr};
         difference_type m_idx{0};
-        difference_type m_numberOfElements;
+        difference_type m_numberOfElements{0};
     };
 
     template <typename TYPE>
@@ -844,6 +845,12 @@ inline const T& Array::at(const size_t& offset) const
     return *(reinterpret_cast<const T*>(this->getBuffer()) + offset);
 }
 
+template <class TYPE, bool isConst>
+inline Array::IteratorBase<TYPE, isConst>::IteratorBase()
+{
+
+}
+
 //------------------------------------------------------------------------------
 
 template <class TYPE, bool isConst>
@@ -907,6 +914,7 @@ inline bool Array::IteratorBase<TYPE, isConst>::operator!=(const IteratorBase& o
 template <typename TYPE, bool isConst>
 inline typename Array::IteratorBase<TYPE, isConst>::reference Array::IteratorBase<TYPE, isConst>::operator*() const
 {
+    SLM_ASSERT("Iterator needs to be initialized", m_pointer);
     return *m_pointer;
 }
 
