@@ -1,7 +1,7 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2015 IRCAD France
- * Copyright (C) 2012-2015 IHU Strasbourg
+ * Copyright (C) 2009-2020 IRCAD France
+ * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
  *
@@ -20,13 +20,12 @@
  *
  ***********************************************************************/
 
-#ifndef __FWMEDDATA_UT_EQUIPMENTTEST_HPP__
-#define __FWMEDDATA_UT_EQUIPMENTTEST_HPP__
-
-#include <cppunit/extensions/HelperMacros.h>
+#pragma once
 
 #include <fwMedData/Equipment.hpp>
 
+#include <cppunit/extensions/HelperMacros.h>
+
 namespace fwMedData
 {
 
@@ -52,6 +51,3 @@ private:
 
 } //namespace ut
 } //namespace fwMedData
-
-#endif //__FWMEDDATA_UT_EQUIPMENTTEST_HPP__
-
