@@ -35,6 +35,7 @@ namespace ut
 class RuntimeTest : public CPPUNIT_NS::TestFixture
 {
 CPPUNIT_TEST_SUITE( RuntimeTest );
+CPPUNIT_TEST( testLibrary );
 CPPUNIT_TEST( testModule );
 CPPUNIT_TEST( testOperations );
 CPPUNIT_TEST_SUITE_END();
@@ -46,6 +47,7 @@ public:
     void setUp();
     void tearDown();
 
+    void testLibrary();
     void testModule();
     void testOperations();
 };
