@@ -1,7 +1,7 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2019 IRCAD France
- * Copyright (C) 2018-2019 IHU Strasbourg
+ * Copyright (C) 2018-2020 IRCAD France
+ * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
  *
@@ -122,7 +122,7 @@ namespace fwServices
         {
             const std::string msg = "All the required inputs are not present, '" + this->getID() +
                                     "' activity will not be launched";
-            ::fwGui::dialog::MessageDialog::showMessageDialog("Manager Initialization",
+            ::fwGui::dialog::MessageDialog::show("Manager Initialization",
                                                               msg,
                                                               ::fwGui::dialog::IMessageDialog::CRITICAL);
         }
