@@ -41,7 +41,7 @@ namespace fwTest
 #define CHECK_VALUE(check, message, val1, val2)                                \
     {                                                                           \
         check &= (val1 == val2);                                                \
-        OSLM_ERROR_IF(message << " <"<< val1 << "> != <" << val2 << ">", val1 != val2 );        \
+        SLM_ERROR_IF(message << " <"<< val1 << "> != <" << val2 << ">", val1 != val2 );        \
     }                                                                           \
 
 //------------------------------------------------------------------------------
@@ -49,7 +49,7 @@ namespace fwTest
 #define CHECK_VALUE_WITH_TOLERANCE(check, message, val1, val2, tol)                                 \
     {                                                                                               \
         check &= ( val1 - tol <= val2 &&  val2 <= val1 + tol );                                    \
-        OSLM_ERROR_IF(message << val1 << " != " << val2, val1 - tol > val2 ||  val2 > val1 + tol ); \
+        SLM_ERROR_IF(message << val1 << " != " << val2, val1 - tol > val2 ||  val2 > val1 + tol ); \
     }
 
 //------------------------------------------------------------------------------
@@ -116,8 +116,8 @@ bool DicomReaderTest::checkSeriesJMSGenou( const ::fwMedData::ImageSeries::sptr&
     {
         fwMedData::DicomValuesType physiciansName;
         ok &= (physiciansName == series->getPerformingPhysiciansName());
-        OSLM_ERROR_IF("Name of the physician(s) administering the Series doesn't match : ",
-                      (physiciansName == series->getPerformingPhysiciansName()));
+        SLM_ERROR_IF("Name of the physician(s) administering the Series doesn't match : ",
+                     (physiciansName == series->getPerformingPhysiciansName()));
     }
     //(0008,1090) LO [Aquilion]                                         # 8,1 Manufacturer's Model Name
     //(0010,0000) UL 104                                                # 4,1 Generic Group Length
@@ -169,7 +169,7 @@ bool DicomReaderTest::checkSeriesJMSGenou( const ::fwMedData::ImageSeries::sptr&
 
     if(!img)
     {
-        OSLM_ERROR( "Missing image." );
+        SLM_ERROR( "Missing image." );
         return false;
     }
 
@@ -310,8 +310,8 @@ bool DicomReaderTest::checkSeriesJMSGenouTrimmed( const ::fwMedData::ImageSeries
     {
         fwMedData::DicomValuesType physiciansName;
         ok &= (physiciansName == series->getPerformingPhysiciansName());
-        OSLM_ERROR_IF("Name of the physician(s) administering the Series doesn't match : ",
-                      (physiciansName == series->getPerformingPhysiciansName()));
+        SLM_ERROR_IF("Name of the physician(s) administering the Series doesn't match : ",
+                     (physiciansName == series->getPerformingPhysiciansName()));
     }
     //(0008,1090) LO [Aquilion]                                         # 8,1 Manufacturer's Model Name
     //(0010,0000) UL 104                                                # 4,1 Generic Group Length
@@ -363,7 +363,7 @@ bool DicomReaderTest::checkSeriesJMSGenouTrimmed( const ::fwMedData::ImageSeries
 
     if(!img)
     {
-        OSLM_ERROR( "Missing image." );
+        SLM_ERROR( "Missing image." );
         return false;
     }
 
