@@ -71,34 +71,35 @@ const ::fwCom::Signals::SignalKeyType Layer::s_RESIZE_LAYER_SIG         = "layer
 const ::fwCom::Signals::SignalKeyType Layer::s_CAMERA_UPDATED_SIG       = "CameraUpdated";
 const ::fwCom::Signals::SignalKeyType Layer::s_CAMERA_RANGE_UPDATED_SIG = "CameraRangeUpdated";
 
-const ::fwCom::Slots::SlotKeyType Layer::s_INTERACTION_SLOT    = "interaction";
-const ::fwCom::Slots::SlotKeyType Layer::s_RESET_CAMERA_SLOT   = "resetCamera";
-const ::fwCom::Slots::SlotKeyType Layer::s_USE_CELSHADING_SLOT = "useCelShading";
+const ::fwCom::Slots::SlotKeyType Layer::s_INTERACTION_SLOT  = "interaction";
+const ::fwCom::Slots::SlotKeyType Layer::s_RESET_CAMERA_SLOT = "resetCamera";
 
 //-----------------------------------------------------------------------------
 
-const std::string Layer::DEFAULT_CAMERA_NAME        = "DefaultCam";
-const std::string Layer::DEFAULT_LIGHT_NAME         = "DefaultLight";
+const std::string Layer::DEFAULT_CAMERA_NAME = "DefaultCam";
+const std::string Layer::DEFAULT_LIGHT_NAME  = "DefaultLight";
+
+const std::string Layer::s_DEFAULT_CAMERA_NAME      = "DefaultCam";
+const std::string Layer::s_DEFAULT_LIGHT_NAME       = "DefaultLight";
 const std::string Layer::s_DEFAULT_CAMERA_NODE_NAME = "CameraNode";
 
 //-----------------------------------------------------------------------------
 
 struct Layer::LayerCameraListener : public ::Ogre::Camera::Listener
 {
-    Layer* m_layer;
-    int m_frameId;
+    Layer* m_layer { nullptr };
+    int m_frameId { 0 };
 
     //------------------------------------------------------------------------------
 
     LayerCameraListener(Layer* renderer) :
-        m_layer(renderer),
-        m_frameId(0)
+        m_layer(renderer)
     {
     }
 
     //------------------------------------------------------------------------------
 
-    virtual void cameraPreRenderScene(::Ogre::Camera*) final
+    void cameraPreRenderScene(::Ogre::Camera*) final
     {
         SLM_ASSERT("Layer is not set", m_layer );
 
@@ -145,26 +146,7 @@ struct Layer::LayerCameraListener : public ::Ogre::Camera::Listener
     //------------------------------------------------------------------------------
 };
 
-Layer::Layer() :
-    m_sceneManager(nullptr),
-    m_renderTarget(nullptr),
-    m_viewport(nullptr),
-    m_stereoMode(compositor::Core::StereoModeType::NONE),
-    m_rawCompositorChain(""),
-    m_coreCompositor(nullptr),
-    m_transparencyTechnique(::fwRenderOgre::compositor::DEFAULT),
-    m_numPeels(8),
-    m_depth(1),
-    m_topColor("#333333"),
-    m_bottomColor("#333333"),
-    m_topScale(0.f),
-    m_bottomScale(1.f),
-    m_camera(nullptr),
-    m_hasCoreCompositor(false),
-    m_hasCompositorChain(false),
-    m_sceneCreated(false),
-    m_hasDefaultLight(true),
-    m_cameraListener(nullptr)
+Layer::Layer()
 {
     newSignal<InitLayerSignalType>(s_INIT_LAYER_SIG);
     newSignal<ResizeLayerSignalType>(s_RESIZE_LAYER_SIG);
@@ -179,26 +161,6 @@ Layer::Layer() :
 
 Layer::~Layer()
 {
-    if(m_camera && m_cameraListener)
-    {
-        m_camera->removeListener(m_cameraListener);
-        delete m_cameraListener;
-        m_cameraListener = nullptr;
-    }
-
-    if(m_autostereoListener)
-    {
-        ::Ogre::MaterialManager::getSingleton().removeListener(m_autostereoListener);
-        delete m_autostereoListener;
-        m_autostereoListener = nullptr;
-    }
-
-    if(m_sceneManager)
-    {
-        ::fwRenderOgre::Utils::getOgreRoot()->destroySceneManager(m_sceneManager);
-        m_sceneManager = nullptr;
-    }
-    m_camera = nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -270,16 +232,16 @@ void Layer::createScene()
     }
 
     // Create the camera
-    m_camera = m_sceneManager->createCamera(Layer::DEFAULT_CAMERA_NAME);
+    m_camera = m_sceneManager->createCamera(Layer::s_DEFAULT_CAMERA_NAME);
     m_camera->setNearClipDistance(1);
 
     const auto&[left, top, width, height] = m_viewportCfg;
-    m_viewport                            = m_renderTarget->addViewport(m_camera, m_depth, left, top, width, height);
+    m_viewport                            = m_renderTarget->addViewport(m_camera, m_order, left, top, width, height);
     m_viewport->setOverlaysEnabled(m_enabledOverlays.size() > 0);
 
     m_compositorChainManager = fwc::ChainManager::uptr(new fwc::ChainManager(m_viewport));
 
-    if (m_depth != 0)
+    if (m_order != 0)
     {
         m_viewport->setClearEveryFrame(true, ::Ogre::FBT_DEPTH);
     } // Set the background material
@@ -349,7 +311,7 @@ void Layer::createScene()
 
         m_lightAdaptor = ::fwRenderOgre::ILight::createLightAdaptor(m_defaultLightDiffuseColor,
                                                                     m_defaultLightSpecularColor);
-        m_lightAdaptor->setName(Layer::DEFAULT_LIGHT_NAME);
+        m_lightAdaptor->setName(Layer::s_DEFAULT_LIGHT_NAME);
         m_lightAdaptor->setType(::Ogre::Light::LT_DIRECTIONAL);
         m_lightAdaptor->setTransformId(cameraNode->getName());
         m_lightAdaptor->setLayerID(this->getLayerID());
@@ -398,11 +360,35 @@ void Layer::createScene()
 
 void Layer::destroyScene()
 {
+    // Remove the background material
+    ::Ogre::MaterialManager::getSingleton().remove(
+        this->getName() + "backgroundMat", ::Ogre::ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
+
     if(m_lightAdaptor)
     {
         ::fwRenderOgre::ILight::destroyLightAdaptor(m_lightAdaptor);
         m_lightAdaptor.reset();
     }
+
+    if(m_camera && m_cameraListener)
+    {
+        m_camera->removeListener(m_cameraListener);
+        delete m_cameraListener;
+        m_cameraListener = nullptr;
+    }
+    if(m_autostereoListener)
+    {
+        ::Ogre::MaterialManager::getSingleton().removeListener(m_autostereoListener);
+        delete m_autostereoListener;
+        m_autostereoListener = nullptr;
+    }
+
+    if(m_sceneManager)
+    {
+        ::fwRenderOgre::Utils::getOgreRoot()->destroySceneManager(m_sceneManager);
+        m_sceneManager = nullptr;
+    }
+    m_camera = nullptr;
 }
 
 // ----------------------------------------------------------------------------
@@ -562,21 +548,34 @@ void Layer::interaction(::fwRenderOgre::IRenderWindowInteractorManager::Interact
     }
 
     m_cancelFurtherInteraction = false;
-    this->signal<CameraUpdatedSignalType>(s_CAMERA_UPDATED_SIG)->asyncEmit();
 }
 
 // ----------------------------------------------------------------------------
 
 int Layer::getDepth() const
 {
-    return m_depth;
+    return m_order;
 }
 
 // ----------------------------------------------------------------------------
 
-void Layer::setDepth(int depth)
+void Layer::setDepth(int _order)
 {
-    m_depth = depth;
+    m_order = _order;
+}
+
+// ----------------------------------------------------------------------------
+
+int Layer::getOrder() const
+{
+    return m_order;
+}
+
+// ----------------------------------------------------------------------------
+
+void Layer::setOrder(int _order)
+{
+    m_order = _order;
 }
 
 // ----------------------------------------------------------------------------
@@ -709,28 +708,36 @@ void Layer::removeInteractor(const ::fwRenderOgre::interactor::IInteractor::sptr
         {
             const ::Ogre::Entity* entity = dynamic_cast< ::Ogre::Entity* > (movable);
 
-            if(entity && entity->isVisible())
+            if(entity)
             {
-                worldCoordBoundingBox.merge(entity->getWorldBoundingBox());
+                if(entity->isVisible())
+                {
+                    worldCoordBoundingBox.merge(entity->getWorldBoundingBox());
+                }
             }
             else
             {
                 // Then try to cast into a ManualObject*
                 const ::Ogre::ManualObject* manualObject = dynamic_cast< ::Ogre::ManualObject* > (movable);
 
-                if(manualObject && manualObject->isVisible())
+                if(manualObject)
                 {
-                    worldCoordBoundingBox.merge(manualObject->getWorldBoundingBox());
+                    if(manualObject->isVisible())
+                    {
+                        worldCoordBoundingBox.merge(manualObject->getWorldBoundingBox());
+                    }
                 }
                 else
                 {
                     // Last try to cast into a Camera*
                     const ::Ogre::Camera* cameraObject = dynamic_cast< ::Ogre::Camera* > (movable);
 
-                    if(cameraObject && cameraObject != this->getDefaultCamera() &&
-                       cameraObject->isDebugDisplayEnabled())
+                    if(cameraObject && cameraObject != this->getDefaultCamera())
                     {
-                        worldCoordBoundingBox.merge(cameraObject->getWorldBoundingBox());
+                        if(cameraObject->isDebugDisplayEnabled())
+                        {
+                            worldCoordBoundingBox.merge(cameraObject->getWorldBoundingBox());
+                        }
                     }
                 }
             }
@@ -826,7 +833,7 @@ bool Layer::isDefaultLight(const ::fwRenderOgre::ILight::csptr& _light) const
 
 void Layer::removeDefaultLight()
 {
-    OSLM_ASSERT("m_lightAdaptor must not be null", m_lightAdaptor != nullptr);
+    SLM_ASSERT("m_lightAdaptor must not be null", m_lightAdaptor != nullptr);
     ::fwRenderOgre::ILight::destroyLightAdaptor(m_lightAdaptor);
     m_lightAdaptor.reset();
 }
@@ -853,7 +860,7 @@ void Layer::resetCameraCoordinates()
                                                    worldCoordBoundingBox.getSize().length() : 0;
 
             float coeffZoom = static_cast<float>(boundingBoxLength);
-            OSLM_DEBUG("Zoom coefficient : " << coeffZoom);
+            SLM_DEBUG("Zoom coefficient : " << coeffZoom);
 
             // Set the direction of the camera
             ::Ogre::SceneNode* camNode = m_camera->getParentSceneNode();
@@ -992,7 +999,6 @@ void Layer::resetCameraClippingRange(const ::Ogre::AxisAlignedBox& worldCoordBou
         if(saoCompositorIt != chain.end() && saoCompositorIt->second)
         {
             // Near and far for SAO
-            OSLM_TRACE("Near SAO");
             maxNear = 1;
             minFar  = 10000;
         }
@@ -1088,7 +1094,7 @@ void Layer::setCoreCompositorEnabled(bool enabled, std::string transparencyTechn
         }
         else
         {
-            OSLM_ERROR("Unknown transparency technique : " << transparencyTechnique);
+            SLM_ERROR("Unknown transparency technique : " << transparencyTechnique);
         }
     }
 
@@ -1384,4 +1390,4 @@ void Layer::cancelFurtherInteraction()
 
 //-----------------------------------------------------------------------------
 
-} // namespace fwRenderOgre
+} // namespace fwRenderOgre.
