@@ -142,16 +142,16 @@ void Mesh::bindLayer(const ::fwData::Mesh::csptr& _mesh, BufferBinding _binding,
     SLM_ASSERT("Invalid vertex buffer binding", bind);
 
     ::Ogre::VertexDeclaration* vtxDecl = m_ogreMesh->sharedVertexData->vertexDeclaration;
-    size_t offset = 0;
 
+    // Create the buffer semantic if it does not exist.
     if(!vtxDecl->findElementBySemantic(_semantic))
     {
         m_binding[_binding] = static_cast<unsigned short>(bind->getBindings().size());
 
-        vtxDecl->addElement(m_binding[_binding], offset, _type, _semantic);
-        offset += ::Ogre::VertexElement::getTypeSize(_type);
+        vtxDecl->addElement(m_binding[_binding], 0, _type, _semantic);
     }
 
+    // Get requested buffer size and previous buffer size.
     ::Ogre::HardwareVertexBufferSharedPtr cbuf;
 
     const size_t uiNumVertices = _mesh->getNumberOfPoints();
@@ -162,6 +162,7 @@ void Mesh::bindLayer(const ::fwData::Mesh::csptr& _mesh, BufferBinding _binding,
         uiPrevNumVertices = cbuf->getNumVertices();
     }
 
+    // Allocate the buffer if it necessary.
     if(!bind->isBufferBound(m_binding[_binding]) || uiPrevNumVertices < uiNumVertices )
     {
         FW_PROFILE_AVG("REALLOC LAYER", 5);
@@ -171,6 +172,8 @@ void Mesh::bindLayer(const ::fwData::Mesh::csptr& _mesh, BufferBinding _binding,
                                               ::Ogre::HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE :
                                               ::Ogre::HardwareBuffer::HBU_STATIC_WRITE_ONLY;
 
+        const size_t offset = ::Ogre::VertexElement::getTypeSize(_type);
+
         ::Ogre::HardwareBufferManager& mgr = ::Ogre::HardwareBufferManager::getSingleton();
         cbuf                               = mgr.createVertexBuffer(offset, uiNumVertices, usage, false);
         bind->setBinding(m_binding[_binding], cbuf);
@@ -199,7 +202,7 @@ void Mesh::updateMesh(const ::fwData::Mesh::sptr& _mesh, bool _pointsOnly)
 
     /// The values in this table refer to vertices in the above table
     const size_t numVertices = _mesh->getNumberOfPoints();
-    OSLM_DEBUG("Vertices #" << numVertices);
+    SLM_DEBUG("Vertices #" << numVertices);
 
     // Check if the mesh has normals - we assume we should have as many normals as points
     // If this is not the case, normals will be ignored or regenerated if needed and if the number of vertices changed
@@ -329,7 +332,7 @@ void Mesh::updateMesh(const ::fwData::Mesh::sptr& _mesh, bool _pointsOnly)
         }
         else
         {
-            OSLM_ERROR("Unhandled cell type in Ogre mesh: " << static_cast<int>(cellType));
+            SLM_ERROR("Unhandled cell type in Ogre mesh: " << static_cast<int>(cellType));
         }
     }
 
@@ -416,7 +419,7 @@ void Mesh::updateMesh(const ::fwData::Mesh::sptr& _mesh, bool _pointsOnly)
                         m_subMeshes[i]->indexData->indexBuffer = ibuf;
                     }
                     m_subMeshes[i]->indexData->indexCount = numIndices[i];
-                    OSLM_DEBUG("Index #" << m_subMeshes[i]->indexData->indexCount );
+                    SLM_DEBUG("Index #" << m_subMeshes[i]->indexData->indexCount );
 
                     // Lock index data, we are going to write into it in the next loop
                     indexBuffer[i] = ibuf->lock(::Ogre::HardwareBuffer::HBL_DISCARD);
@@ -482,7 +485,7 @@ void Mesh::updateMesh(const ::fwData::PointList::csptr& _pointList)
 
     /// The values in this table refer to vertices in the above table
     size_t uiNumVertices = points.size();
-    OSLM_DEBUG("Vertices #" << uiNumVertices);
+    SLM_DEBUG("Vertices #" << uiNumVertices);
 
     // Check if mesh attributes
     m_hasNormal = false;
