@@ -112,6 +112,7 @@ void Plane::initializeMaterial()
 {
     auto& materialMgr = ::Ogre::MaterialManager::getSingleton();
     ::Ogre::MaterialPtr defaultMat = materialMgr.getByName("Negato");
+    SLM_ASSERT("Default material not found, the 'material' module may not be loaded.", defaultMat);
 
     // If the texture material exists, delete it.
     if(m_texMaterial)
@@ -176,8 +177,8 @@ void Plane::initializeMaterial()
         m_borderMaterial = m_borderMaterial->clone(m_slicePlaneName + "_BorderMaterial");
         if(m_orientation == ::fwDataTools::helper::MedicalImage::Orientation::X_AXIS)
         {
-            m_borderMaterial->setAmbient(::Ogre::ColourValue::Red);
-            m_borderMaterial->setDiffuse(::Ogre::ColourValue::Red);
+            m_borderMaterial->setAmbient(::Ogre::ColourValue::Blue);
+            m_borderMaterial->setDiffuse(::Ogre::ColourValue::Blue);
         }
         else if(m_orientation == ::fwDataTools::helper::MedicalImage::Orientation::Y_AXIS)
         {
@@ -186,8 +187,8 @@ void Plane::initializeMaterial()
         }
         else
         {
-            m_borderMaterial->setAmbient(::Ogre::ColourValue::Blue);
-            m_borderMaterial->setDiffuse(::Ogre::ColourValue::Blue);
+            m_borderMaterial->setAmbient(::Ogre::ColourValue::Red);
+            m_borderMaterial->setDiffuse(::Ogre::ColourValue::Red);
         }
     }
 }
@@ -264,27 +265,33 @@ void Plane::initializePlane()
 
         if(m_orientation == ::fwDataTools::helper::MedicalImage::Orientation::X_AXIS)
         {
-            m_border->position(::Ogre::Vector3(0, -m_height/2.f, -m_width/2.f));
-            m_border->position(::Ogre::Vector3(0, m_height/2.f, -m_width/2.f));
-            m_border->position(::Ogre::Vector3(0, m_height/2.f, m_width/2.f));
-            m_border->position(::Ogre::Vector3(0, -m_height/2.f, m_width/2.f));
-            m_border->position(::Ogre::Vector3(0, -m_height/2.f, -m_width/2.f));
+            m_border->position(::Ogre::Vector3(0.f, -m_height/2.f, -m_width/2.f));
+            m_border->position(::Ogre::Vector3(0.f, m_height/2.f, -m_width/2.f));
+            m_border->position(::Ogre::Vector3(0.f, m_height/2.f, m_width/2.f));
+            m_border->position(::Ogre::Vector3(0.f, -m_height/2.f, m_width/2.f));
+            m_border->position(::Ogre::Vector3(0.f, -m_height/2.f, -m_width/2.f));
+            m_border->setBoundingBox(::Ogre::AxisAlignedBox(::Ogre::Vector3(0.f, -m_height/2.f, -m_width/2.f),
+                                                            ::Ogre::Vector3(0.f, m_height/2.f, m_width/2.f)));
         }
         else if(m_orientation == ::fwDataTools::helper::MedicalImage::Orientation::Y_AXIS)
         {
-            m_border->position(::Ogre::Vector3(-m_width/2.f, 0, -m_height/2.f));
-            m_border->position(::Ogre::Vector3(m_width/2.f, 0, -m_height/2.f));
-            m_border->position(::Ogre::Vector3(m_width/2.f, 0, m_height/2.f));
-            m_border->position(::Ogre::Vector3(-m_width/2.f, 0, m_height/2.f));
-            m_border->position(::Ogre::Vector3(-m_width/2.f, 0, -m_height/2.f));
+            m_border->position(::Ogre::Vector3(-m_width/2.f, 0.f, -m_height/2.f));
+            m_border->position(::Ogre::Vector3(m_width/2.f, 0.f, -m_height/2.f));
+            m_border->position(::Ogre::Vector3(m_width/2.f, 0.f, m_height/2.f));
+            m_border->position(::Ogre::Vector3(-m_width/2.f, 0.f, m_height/2.f));
+            m_border->position(::Ogre::Vector3(-m_width/2.f, 0.f, -m_height/2.f));
+            m_border->setBoundingBox(::Ogre::AxisAlignedBox(::Ogre::Vector3(-m_height/2.f, 0.f, -m_width/2.f),
+                                                            ::Ogre::Vector3(m_height/2.f, 0.f, m_width/2.f)));
         }
         else
         {
-            m_border->position(::Ogre::Vector3(-m_width/2.f, -m_height/2.f, 0));
-            m_border->position(::Ogre::Vector3(m_width/2.f, -m_height/2.f, 0));
-            m_border->position(::Ogre::Vector3(m_width/2.f, m_height/2.f, 0));
-            m_border->position(::Ogre::Vector3(-m_width/2.f, m_height/2.f, 0));
-            m_border->position(::Ogre::Vector3(-m_width/2.f, -m_height/2.f, 0));
+            m_border->position(::Ogre::Vector3(-m_width/2.f, -m_height/2.f, 0.f));
+            m_border->position(::Ogre::Vector3(m_width/2.f, -m_height/2.f, 0.f));
+            m_border->position(::Ogre::Vector3(m_width/2.f, m_height/2.f, 0.f));
+            m_border->position(::Ogre::Vector3(-m_width/2.f, m_height/2.f, 0.f));
+            m_border->position(::Ogre::Vector3(-m_width/2.f, -m_height/2.f, 0.f));
+            m_border->setBoundingBox(::Ogre::AxisAlignedBox(::Ogre::Vector3(-m_height/2.f, -m_width/2.f, 0.f),
+                                                            ::Ogre::Vector3(m_height/2.f, m_width/2.f, 0.f)));
         }
 
         m_border->end();
@@ -612,4 +619,5 @@ void Plane::setRenderQueuerGroupAndPriority(std::uint8_t _groupId, std::uint16_t
 }
 
 //-----------------------------------------------------------------------------
-} // namespace fwRenderOgre
+
+} // namespace fwRenderOgre.
