@@ -1,7 +1,7 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2019 IRCAD France
- * Copyright (C) 2014-2019 IHU Strasbourg
+ * Copyright (C) 2014-2020 IRCAD France
+ * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
  *
@@ -70,6 +70,7 @@ const ::fwCom::Signals::SignalKeyType SRender::s_FULLSCREEN_SET_SIG     = "fulls
 //-----------------------------------------------------------------------------
 
 const ::fwCom::Slots::SlotKeyType SRender::s_COMPUTE_CAMERA_ORIG_SLOT     = "computeCameraParameters";
+const ::fwCom::Slots::SlotKeyType SRender::s_RESET_CAMERAS_SLOT           = "resetCameras";
 const ::fwCom::Slots::SlotKeyType SRender::s_COMPUTE_CAMERA_CLIPPING_SLOT = "computeCameraClipping";
 const ::fwCom::Slots::SlotKeyType SRender::s_REQUEST_RENDER_SLOT          = "requestRender";
 const ::fwCom::Slots::SlotKeyType SRender::s_DISABLE_FULLSCREEN           = "disableFullscreen";
@@ -89,6 +90,7 @@ SRender::SRender() noexcept
     m_fullscreenSetSig = newSignal<FullscreenSetSignalType>(s_FULLSCREEN_SET_SIG);
 
     newSlot(s_COMPUTE_CAMERA_ORIG_SLOT, &SRender::resetCameraCoordinates, this);
+    newSlot(s_RESET_CAMERAS_SLOT, &SRender::resetCameras, this);
     newSlot(s_COMPUTE_CAMERA_CLIPPING_SLOT, &SRender::computeCameraClipping, this);
     newSlot(s_REQUEST_RENDER_SLOT, &SRender::requestRender, this);
     newSlot(s_DISABLE_FULLSCREEN, &SRender::disableFullscreen, this);
@@ -171,7 +173,6 @@ void SRender::configuring()
 
 void SRender::starting()
 {
-    SLM_TRACE_FUNC();
 
     bool bHasBackground = false;
 
@@ -195,14 +196,14 @@ void SRender::starting()
     auto bkgConfigs = sceneCfg.equal_range("background");
     for( auto it = bkgConfigs.first; it != bkgConfigs.second; ++it )
     {
-        OSLM_ERROR_IF("A background has already been set, overriding it...", bHasBackground);
+        SLM_ERROR_IF("A background has already been set, overriding it...", bHasBackground);
         try
         {
             this->configureBackgroundLayer(it->second);
         }
         catch (std::exception& e)
         {
-            OSLM_ERROR("Error configuring background for layer '" + this->getID() + "': " + e.what());
+            SLM_ERROR("Error configuring background for layer '" + this->getID() + "': " + e.what());
         }
 
         bHasBackground = true;
@@ -214,7 +215,7 @@ void SRender::starting()
         ::fwRenderOgre::Layer::sptr ogreLayer = ::fwRenderOgre::Layer::New();
         ogreLayer->setRenderService(::fwRenderOgre::SRender::dynamicCast(this->shared_from_this()));
         ogreLayer->setID("backgroundLayer");
-        ogreLayer->setDepth(0);
+        ogreLayer->setOrder(0);
         ogreLayer->setWorker(m_associatedWorker);
         ogreLayer->setBackgroundColor("#000000", "#000000");
         ogreLayer->setBackgroundScale(0, 0.5);
@@ -264,8 +265,6 @@ void SRender::stopping()
 {
     this->makeCurrent();
 
-    m_connections.disconnect();
-
     m_interactorManager->getRenderTarget()->removeAllListeners();
     m_viewportOverlaysMap.clear();
 
@@ -323,8 +322,18 @@ void SRender::configureLayer(const ConfigType& _cfg )
                 stereoMode.empty() || stereoMode == "no" || stereoMode == "AutoStereo5" || stereoMode == "AutoStereo8" ||
                 stereoMode == "Stereo");
 
-    const int layerDepth = attributes.get<int>("depth");
-    SLM_ASSERT("Attribute 'depth' must be greater than 0", layerDepth > 0);
+    int layerOrder        = 0;
+    const auto layerDepth = attributes.get_optional<int>("depth");
+    if(layerDepth)
+    {
+        FW_DEPRECATED_MSG("Attribute 'depth' is deprecated, please used 'order' instead", "22.0")
+        layerOrder = layerDepth.get();
+    }
+    else
+    {
+        layerOrder = attributes.get<int>("order");
+    }
+    SLM_ASSERT("Attribute 'order' must be greater than 0", layerOrder > 0);
 
     ::fwRenderOgre::Layer::sptr ogreLayer = ::fwRenderOgre::Layer::New();
     compositor::Core::StereoModeType layerStereoMode =
@@ -335,7 +344,7 @@ void SRender::configureLayer(const ConfigType& _cfg )
 
     ogreLayer->setRenderService(::fwRenderOgre::SRender::dynamicCast(this->shared_from_this()));
     ogreLayer->setID(id);
-    ogreLayer->setDepth(layerDepth);
+    ogreLayer->setOrder(layerOrder);
     ogreLayer->setWorker(m_associatedWorker);
     ogreLayer->setCoreCompositorEnabled(true, transparencyTechnique, numPeels, layerStereoMode);
     ogreLayer->setCompositorChainEnabled(compositors);
@@ -361,14 +370,19 @@ void SRender::configureBackgroundLayer(const ConfigType& _cfg )
     ::fwRenderOgre::Layer::sptr ogreLayer = ::fwRenderOgre::Layer::New();
     ogreLayer->setRenderService(::fwRenderOgre::SRender::dynamicCast(this->shared_from_this()));
     ogreLayer->setID(s_OGREBACKGROUNDID);
-    ogreLayer->setDepth(0);
+    ogreLayer->setOrder(0);
     ogreLayer->setWorker(m_associatedWorker);
     ogreLayer->setHasDefaultLight(false);
 
-    if (attributes.count("topColor") && attributes.count("bottomColor"))
+    if (attributes.count("color") )
     {
-        std::string topColor = attributes.get<std::string>("topColor");
-        std::string botColor = attributes.get<std::string>("bottomColor");
+        const std::string color = attributes.get<std::string>("color");
+        ogreLayer->setBackgroundColor(color, color);
+    }
+    else if (attributes.count("topColor") && attributes.count("bottomColor"))
+    {
+        const std::string topColor = attributes.get<std::string>("topColor");
+        const std::string botColor = attributes.get<std::string>("bottomColor");
 
         ogreLayer->setBackgroundColor(topColor, botColor);
     }
@@ -380,6 +394,10 @@ void SRender::configureBackgroundLayer(const ConfigType& _cfg )
 
         ogreLayer->setBackgroundScale(topScaleVal, botScaleVal);
     }
+    else
+    {
+        ogreLayer->setBackgroundScale(0.5f, 0.5f);
+    }
 
     m_layers[s_OGREBACKGROUNDID] = ogreLayer;
 }
@@ -475,6 +493,18 @@ void SRender::resetCameraCoordinates(const std::string& _layerId)
 
 //-----------------------------------------------------------------------------
 
+void SRender::resetCameras()
+{
+    for(auto layer : m_layers)
+    {
+        layer.second->resetCameraCoordinates();
+    }
+
+    this->requestRender();
+}
+
+//-----------------------------------------------------------------------------
+
 void SRender::computeCameraClipping()
 {
     for (auto it : m_layers)
@@ -510,8 +540,8 @@ bool SRender::isShownOnScreen()
 
 ::fwRenderOgre::Layer::sptr SRender::getLayer(const ::std::string& sceneID)
 {
-    OSLM_ASSERT("Empty sceneID", !sceneID.empty());
-    OSLM_ASSERT("Layer ID "<< sceneID <<" does not exist", m_layers.find(sceneID) != m_layers.end());
+    SLM_ASSERT("Empty sceneID", !sceneID.empty());
+    SLM_ASSERT("Layer ID "<< sceneID <<" does not exist", m_layers.find(sceneID) != m_layers.end());
 
     ::fwRenderOgre::Layer::sptr layer = m_layers.at(sceneID);
 
@@ -544,10 +574,10 @@ void SRender::disableFullscreen()
 
 // ----------------------------------------------------------------------------
 
-void SRender::enableFullscreen(int screen)
+void SRender::enableFullscreen(int _screen)
 {
     m_fullscreen = true;
-    m_interactorManager->setFullscreen(m_fullscreen, screen);
+    m_interactorManager->setFullscreen(m_fullscreen, _screen);
 
     m_fullscreenSetSig->asyncEmit(true);
 }
