@@ -55,6 +55,8 @@
 
 #include <fwServices/macros.hpp>
 
+#include <fwTools/System.hpp>
+
 #include <fwZip/WriteDirArchive.hpp>
 #include <fwZip/WriteZipArchive.hpp>
 
@@ -155,6 +157,7 @@ void SWriter::configuring()
             {
                 m_allowedExts.insert(m_allowedExts.end(), ext);
                 m_allowedExtLabels[ext] = it->second.get("<xmlattr>.label", "");
+                SLM_ASSERT("No label given for extension '" + ext + "'", !m_allowedExtLabels[ext].empty());
             }
         }
     }
@@ -231,7 +234,7 @@ bool SWriter::versionSelection()
                     }
                     catch ( std::out_of_range e)
                     {
-                        OSLM_ERROR("Bad version format: either " + _a + " or " + _b);
+                        SLM_ERROR("Bad version format: either " + _a + " or " + _b);
                         return false;
                     }
                 });
@@ -253,7 +256,7 @@ bool SWriter::versionSelection()
                 }
                 catch ( std::out_of_range e)
                 {
-                    OSLM_ERROR("Bad version format: " + v);
+                    SLM_ERROR("Bad version format: " + v);
 
                     prettyVersionsAll.push_back(v);
                     prettyVersionsToVersions[ v ] = v;
@@ -346,9 +349,9 @@ void SWriter::updating()
         else
         {
             const std::string errorMessage("File extension '" + requestedExtension + "' is not handled.");
-            ::fwGui::dialog::MessageDialog::showMessageDialog("Medical data writer failed",
-                                                              errorMessage,
-                                                              ::fwGui::dialog::IMessageDialog::CRITICAL);
+            ::fwGui::dialog::MessageDialog::show("Medical data writer failed",
+                                                 errorMessage,
+                                                 ::fwGui::dialog::IMessageDialog::CRITICAL);
             m_writeFailed = true;
             return;
         }
@@ -375,8 +378,6 @@ void SWriter::updating()
 
     FW_RAISE_IF( "Extension is empty", extension.empty() );
 
-    const std::filesystem::path filename = filePath.filename();
-
     FW_RAISE_IF("The file extension '" << extension << "' is not managed",
                 m_allowedExts.find(extension) == m_allowedExts.end());
 
@@ -429,6 +430,11 @@ void SWriter::updating()
                                                          m_associatedWorker
                                                          );
 
+    // Generate a temporary file name for saving the file.
+    const std::filesystem::path tmpFolderPath = ::fwTools::System::getTemporaryFolder();
+    const std::filesystem::path tmpFilePath   = tmpFolderPath / (::fwTools::System::genTempFileName() + ".sight");
+    const std::filesystem::path tmpFilename   = tmpFilePath.filename();
+
     // Writing file : job 3
     ::fwJobs::Job::sptr writeJob = ::fwJobs::Job::New("Writing " + extension + " file",
                                                       [ =, &atom](::fwJobs::Job& runningJob)
@@ -440,43 +446,32 @@ void SWriter::updating()
             std::filesystem::path archiveRootName;
             if ( extension == ".json" )
             {
-                writeArchive    = ::fwZip::WriteDirArchive::New(folderPath.string());
-                archiveRootName = filename;
+                writeArchive    = ::fwZip::WriteDirArchive::New(tmpFolderPath.string());
+                archiveRootName = tmpFilename;
                 format          = ::fwAtomsBoostIO::JSON;
             }
             else if ( extension == ".jsonz")
             {
-                if ( std::filesystem::exists( filePath ) )
-                {
-                    std::filesystem::remove( filePath );
-                }
-                writeArchive    = ::fwZip::WriteZipArchive::New(filePath.string());
+                writeArchive    = ::fwZip::WriteZipArchive::New(tmpFilePath.string());
                 archiveRootName = "root.json";
                 format          = ::fwAtomsBoostIO::JSON;
             }
             else if ( extension == ".cpz" )
             {
-                if ( std::filesystem::exists( filePath ) )
-                {
-                    std::filesystem::remove( filePath );
-                }
-                writeArchive    = ::fwZip::WriteZipArchive::New(filePath.string(), "", ::fwPreferences::getPassword());
+                writeArchive = ::fwZip::WriteZipArchive::New(tmpFilePath.string(), "",
+                                                             ::fwPreferences::getPassword());
                 archiveRootName = "root.json";
                 format          = ::fwAtomsBoostIO::JSON;
             }
             else if ( extension == ".xml" )
             {
-                writeArchive    = ::fwZip::WriteDirArchive::New(folderPath.string());
-                archiveRootName = filename;
+                writeArchive    = ::fwZip::WriteDirArchive::New(tmpFolderPath.string());
+                archiveRootName = tmpFilename;
                 format          = ::fwAtomsBoostIO::XML;
             }
             else if ( extension == ".xmlz" )
             {
-                if ( std::filesystem::exists( filePath ) )
-                {
-                    std::filesystem::remove( filePath );
-                }
-                writeArchive    = ::fwZip::WriteZipArchive::New(filePath.string());
+                writeArchive    = ::fwZip::WriteZipArchive::New(tmpFilePath.string());
                 archiveRootName = "root.xml";
                 format          = ::fwAtomsBoostIO::XML;
             }
@@ -485,9 +480,25 @@ void SWriter::updating()
                 FW_RAISE( "This file extension '" << extension << "' is not managed" );
             }
 
-            ::fwAtomsBoostIO::Writer(atom).write( writeArchive, archiveRootName, format );
+            const std::filesystem::path folderDirName =
+                ::fwAtomsBoostIO::Writer(atom).write( writeArchive, archiveRootName, format );
             writeArchive.reset();
 
+            // If the save is successful, remove the old file if it exists.
+            if(std::filesystem::exists(filePath))
+            {
+                std::filesystem::remove(filePath);
+            }
+
+            // Rename the temporary file with the real name and move it to the right folder.
+
+            ::fwTools::System::robustRename(tmpFilePath, filePath);
+
+            if(std::filesystem::exists(tmpFolderPath/folderDirName))
+            {
+                ::fwTools::System::robustRename(tmpFolderPath/folderDirName, folderPath/folderDirName);
+            }
+
             runningJob.done();
         }, m_associatedWorker );
 
@@ -503,19 +514,33 @@ void SWriter::updating()
     {
         jobs->run().get();
     }
-    catch( std::exception& e )
+    catch(std::exception& _e)
     {
-        OSLM_ERROR( e.what() );
-        ::fwGui::dialog::MessageDialog::showMessageDialog("Medical data writer failed",
-                                                          e.what(),
-                                                          ::fwGui::dialog::IMessageDialog::CRITICAL);
+        // Delete the temporary file if the process failed.
+        if(std::filesystem::exists(tmpFilePath))
+        {
+            std::filesystem::remove(tmpFilePath);
+        }
+
+        // Handle the error.
+        SLM_ERROR(_e.what());
+        ::fwGui::dialog::MessageDialog::show("Medical data writer failed",
+                                             _e.what(),
+                                             ::fwGui::dialog::IMessageDialog::CRITICAL);
         m_writeFailed = true;
     }
-    catch( ... )
+    catch(...)
     {
-        ::fwGui::dialog::MessageDialog::showMessageDialog("Medical data writer failed",
-                                                          "Writing process aborted",
-                                                          ::fwGui::dialog::IMessageDialog::CRITICAL);
+        // Delete the temporary file if the process failed.
+        if(std::filesystem::exists(tmpFilePath))
+        {
+            std::filesystem::remove(tmpFilePath);
+        }
+
+        // Handle the error.
+        ::fwGui::dialog::MessageDialog::show("Medical data writer failed",
+                                             "Writing process aborted",
+                                             ::fwGui::dialog::IMessageDialog::CRITICAL);
         m_writeFailed = true;
     }
 
@@ -532,6 +557,13 @@ void SWriter::updating()
 //-----------------------------------------------------------------------------
 
 void SWriter::configureWithIHM()
+{
+    this->openLocationDialog();
+}
+
+//-----------------------------------------------------------------------------
+
+void SWriter::openLocationDialog()
 {
     static std::filesystem::path _sDefaultPath;
 
@@ -564,7 +596,6 @@ void SWriter::configureWithIHM()
         }
 
     }
-
 }
 
 //-----------------------------------------------------------------------------
