@@ -41,6 +41,8 @@
 
 #include <fwServices/macros.hpp>
 
+#include <openvslamIO/Helper.hpp>
+
 #include <opencv2/core.hpp>
 #include <opencv2/imgproc.hpp>
 
@@ -52,8 +54,6 @@
 #include <openvslam/publish/map_publisher.h>
 #include <openvslam/system.h>
 
-#include <openvslamIO/Helper.hpp>
-
 namespace openvslamTracker
 {
 
@@ -744,7 +744,7 @@ void SOpenvslam::tracking(::fwCore::HiResClock::HiResClockType& timestamp)
         }
         catch (std::exception& e)
         {
-            OSLM_ERROR("Error processing openvslam: " << e.what());
+            SLM_ERROR("Error processing openvslam: " << e.what());
             return;
         }
 
@@ -809,9 +809,9 @@ void SOpenvslam::loadVocabulary(const std::string& _filePath)
 {
     if(_filePath.empty())
     {
-        ::fwGui::dialog::MessageDialog::showMessageDialog("Vocabulary",
-                                                          "Vocabulary file : "+_filePath + " can not be loaded.",
-                                                          ::fwGui::dialog::MessageDialog::WARNING);
+        ::fwGui::dialog::MessageDialog::show("Vocabulary",
+                                             "Vocabulary file : "+_filePath + " can not be loaded.",
+                                             ::fwGui::dialog::MessageDialog::WARNING);
         m_sigVocFileUnloaded->asyncEmit();
     }
     else
