@@ -1,7 +1,7 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2019 IRCAD France
- * Copyright (C) 2014-2019 IHU Strasbourg
+ * Copyright (C) 2014-2020 IRCAD France
+ * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
  *
@@ -41,12 +41,11 @@
 
 #include <fwTools/Type.hpp>
 
-#include <filesystem>
-
 #include <opencv2/imgcodecs.hpp>
 #include <opencv2/imgproc.hpp>
 
 #include <chrono>
+#include <filesystem>
 #include <regex>
 
 namespace videoOpenCV
@@ -72,8 +71,6 @@ SFrameGrabber::SFrameGrabber() noexcept :
     m_stepChanged(1),
     m_videoFramesNb(0)
 {
-    m_worker = ::fwThread::Worker::New();
-
     newSlot(s_SET_STEP_SLOT, &SFrameGrabber::setStep, this);
 }
 
@@ -87,6 +84,7 @@ SFrameGrabber::~SFrameGrabber() noexcept
 
 void SFrameGrabber::starting()
 {
+    m_worker = ::fwThread::Worker::New();
 }
 
 // -----------------------------------------------------------------------------
@@ -94,6 +92,9 @@ void SFrameGrabber::starting()
 void SFrameGrabber::stopping()
 {
     this->stopCamera();
+
+    m_worker->stop();
+    m_worker.reset();
 }
 
 // -----------------------------------------------------------------------------
@@ -112,10 +113,10 @@ void SFrameGrabber::configuring()
 
     m_defaultDuration = config.get<double>("defaultDuration", m_defaultDuration);
 
-    OSLM_FATAL_IF("Fps setting is set to " << m_fps << " but should be in ]0;60].", m_fps == 0 || m_fps > 60);
+    SLM_FATAL_IF("Fps setting is set to " << m_fps << " but should be in ]0;60].", m_fps == 0 || m_fps > 60);
 
     m_step = config.get<unsigned long>("step", m_step);
-    OSLM_ASSERT("Step value is set to " << m_step << " but should be > 0.", m_step > 0);
+    SLM_ASSERT("Step value is set to " << m_step << " but should be > 0.", m_step > 0);
     m_stepChanged = m_step;
 }
 
@@ -172,7 +173,7 @@ void SFrameGrabber::startCamera()
     else
     {
         this->setStartState(false);
-        ::fwGui::dialog::MessageDialog::showMessageDialog(
+        ::fwGui::dialog::MessageDialog::show(
             "Grabber",
             "This video source is not managed by this grabber.");
     }
@@ -251,7 +252,7 @@ void SFrameGrabber::readVideo(const std::filesystem::path& file)
 
         if(fps == 0)
         {
-            ::fwGui::dialog::MessageDialog::showMessageDialog(
+            ::fwGui::dialog::MessageDialog::show(
                 "Video error",
                 "Cannot read FPS from video file. Please check the video format.",
                 ::fwGui::dialog::MessageDialog::CRITICAL);
@@ -277,7 +278,7 @@ void SFrameGrabber::readVideo(const std::filesystem::path& file)
     }
     else
     {
-        ::fwGui::dialog::MessageDialog::showMessageDialog(
+        ::fwGui::dialog::MessageDialog::show(
             "Grabber",
             "This file cannot be opened: " + file.string() + ".");
 
@@ -306,7 +307,7 @@ void SFrameGrabber::readDevice( const ::arData::Camera::csptr _camera)
         }
         else
         {
-            ::fwGui::dialog::MessageDialog::showMessageDialog(
+            ::fwGui::dialog::MessageDialog::show(
                 "Grabber",
                 "This device cannot be opened: " + device + " at index: " + std::to_string(index));
         }
@@ -323,7 +324,7 @@ void SFrameGrabber::readDevice( const ::arData::Camera::csptr _camera)
     }
     else
     {
-        ::fwGui::dialog::MessageDialog::showMessageDialog(
+        ::fwGui::dialog::MessageDialog::show(
             "Grabber",
             "This device cannot be opened: " + device + " at index: " + std::to_string(index));
     }
@@ -354,7 +355,7 @@ void SFrameGrabber::readDevice( const ::arData::Camera::csptr _camera)
     }
     else
     {
-        ::fwGui::dialog::MessageDialog::showMessageDialog(
+        ::fwGui::dialog::MessageDialog::show(
             "Grabber",
             "This device:" + device + " at index: " + std::to_string(index) + "cannot be openned.");
 
@@ -392,7 +393,7 @@ void SFrameGrabber::readStream( const ::arData::Camera::csptr _camera)
     }
     else
     {
-        ::fwGui::dialog::MessageDialog::showMessageDialog(
+        ::fwGui::dialog::MessageDialog::show(
             "Grabber",
             "This stream:" + _camera->getStreamUrl() + " cannot be opened.");
 
@@ -477,7 +478,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
                     frameTL->initPoolSize(w, h, ::fwTools::Type::s_UINT16, 1);
                     break;
                 default:
-                    ::fwGui::dialog::MessageDialog::showMessageDialog(
+                    ::fwGui::dialog::MessageDialog::show(
                         "Grabber",
                         "This file cannot be opened: " + file + ".");
                     return;
@@ -509,6 +510,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
             m_timer = m_worker->createTimer();
             m_timer->setOneShot(true);
             m_timer->setFunction(std::bind(&SFrameGrabber::grabImage, this));
+            m_timer->setDuration(std::chrono::milliseconds(0));
             m_timer->start();
         }
         else
@@ -528,7 +530,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
             }
             else
             {
-                OSLM_ERROR("Only one image to read, set 'oneShot' mode to true.");
+                SLM_ERROR("Only one image to read, set 'oneShot' mode to true.");
                 return;
             }
 
@@ -572,8 +574,8 @@ void SFrameGrabber::grabVideo()
 
                 if (width != w || height != h)
                 {
-                    OSLM_ERROR("This video cannot be read, the frame size is not expected. expected: "
-                               << width << " x " << height << ", actual: " << w << " x " << h);
+                    SLM_ERROR("This video cannot be read, the frame size is not expected. expected: "
+                              << width << " x " << height << ", actual: " << w << " x " << h);
                     return;
                 }
 
@@ -592,7 +594,7 @@ void SFrameGrabber::grabVideo()
                         frameTL->initPoolSize(width, height, ::fwTools::Type::s_UINT16, 1);
                         break;
                     default:
-                        ::fwGui::dialog::MessageDialog::showMessageDialog(
+                        ::fwGui::dialog::MessageDialog::show(
                             "Grabber",
                             "This video cannot be read, the video type is not managed.");
                         return;
@@ -677,7 +679,7 @@ void SFrameGrabber::grabImage()
             timestamp = m_imageTimestamps[m_imageCount];
         }
 
-        OSLM_DEBUG("Reading image index " << m_imageCount << " with timestamp " << timestamp);
+        SLM_DEBUG("Reading image index " << m_imageCount << " with timestamp " << timestamp);
 
         const size_t width  = static_cast<size_t>(image.size().width);
         const size_t height = static_cast<size_t>(image.size().height);
@@ -817,7 +819,7 @@ void SFrameGrabber::nextImage()
         }
         else
         {
-            ::fwGui::dialog::MessageDialog::showMessageDialog(
+            ::fwGui::dialog::MessageDialog::show(
                 "Grabber", "No more image to read.");
         }
 
@@ -845,7 +847,7 @@ void SFrameGrabber::previousImage()
         }
         else
         {
-            ::fwGui::dialog::MessageDialog::showMessageDialog(
+            ::fwGui::dialog::MessageDialog::show(
                 "Grabber", "No previous image.");
         }
 
@@ -858,13 +860,13 @@ void SFrameGrabber::setStep(int step, std::string key)
 {
     if(key == "step")
     {
-        OSLM_ASSERT("Needed step value (" << step << ") should be > 0.", step > 0);
+        SLM_ASSERT("Needed step value (" << step << ") should be > 0.", step > 0);
         // Save the changed step value
         m_stepChanged = static_cast<unsigned long>(step);
     }
     else
     {
-        OSLM_WARN("Only 'step' key is supported (current key value is : '" << key << "').");
+        SLM_WARN("Only 'step' key is supported (current key value is : '" << key << "').");
     }
 }
 
