@@ -52,12 +52,10 @@
 namespace visuOgreAdaptor
 {
 
-static const ::fwCom::Slots::SlotKeyType s_NEWIMAGE_SLOT          = "newImage";
-static const ::fwCom::Slots::SlotKeyType s_SLICETYPE_SLOT         = "sliceType";
-static const ::fwCom::Slots::SlotKeyType s_SLICEINDEX_SLOT        = "sliceIndex";
-static const ::fwCom::Slots::SlotKeyType s_UPDATE_OPACITY_SLOT    = "updateOpacity";
-static const ::fwCom::Slots::SlotKeyType s_UPDATE_VISIBILITY_SLOT = "updateVisibility";
-static const ::fwCom::Slots::SlotKeyType s_SET_VISIBILITY_SLOT    = "setVisibility";
+static const ::fwCom::Slots::SlotKeyType s_NEWIMAGE_SLOT       = "newImage";
+static const ::fwCom::Slots::SlotKeyType s_SLICETYPE_SLOT      = "sliceType";
+static const ::fwCom::Slots::SlotKeyType s_SLICEINDEX_SLOT     = "sliceIndex";
+static const ::fwCom::Slots::SlotKeyType s_UPDATE_OPACITY_SLOT = "updateOpacity";
 
 static const ::fwCom::Signals::SignalKeyType s_PICKED_VOXEL_SIG = "pickedVoxel";
 
@@ -87,8 +85,7 @@ SNegato3D::SNegato3D() noexcept :
     newSlot(s_SLICETYPE_SLOT, &SNegato3D::changeSliceType, this);
     newSlot(s_SLICEINDEX_SLOT, &SNegato3D::changeSliceIndex, this);
     newSlot(s_UPDATE_OPACITY_SLOT, &SNegato3D::setPlanesOpacity, this);
-    newSlot(s_UPDATE_VISIBILITY_SLOT, &SNegato3D::setPlanesOpacity, this);
-    newSlot(s_SET_VISIBILITY_SLOT, &SNegato3D::setVisibility, this);
+    newSlot("setVisibility", &SNegato3D::updateVisibility, this);
 
     m_pickedVoxelSignal = newSignal<PickedVoxelSigType>(s_PICKED_VOXEL_SIG);
 }
@@ -218,6 +215,9 @@ void SNegato3D::starting()
         m_pickingCross->setRenderQueueGroupAndPriority(s_NEGATO_WIDGET_RQ_GROUP_ID, 1);
         m_negatoSceneNode->attachObject(m_pickingCross);
     }
+
+    // Set the visibility of the 3D Negato
+    this->setVisible(m_isVisible);
 }
 
 //-----------------------------------------------------------------------------
@@ -230,7 +230,7 @@ void SNegato3D::starting()
     connections.push( s_IMAGE_INOUT, ::fwData::Image::s_SLICE_TYPE_MODIFIED_SIG, s_SLICETYPE_SLOT );
     connections.push( s_IMAGE_INOUT, ::fwData::Image::s_SLICE_INDEX_MODIFIED_SIG, s_SLICEINDEX_SLOT );
     connections.push( s_IMAGE_INOUT, ::fwData::Image::s_VISIBILITY_MODIFIED_SIG, s_UPDATE_VISIBILITY_SLOT );
-    connections.push( s_IMAGE_INOUT, ::fwData::Image::s_TRANSPARENCY_MODIFIED_SIG, s_UPDATE_VISIBILITY_SLOT );
+    connections.push( s_IMAGE_INOUT, ::fwData::Image::s_TRANSPARENCY_MODIFIED_SIG, s_UPDATE_OPACITY_SLOT );
     return connections;
 }
 
@@ -337,17 +337,26 @@ void SNegato3D::newImage()
         this->createPlanes(spacing, origin);
 
         // Update Slice
-        const auto axialIndex =
-            image->getField< ::fwData::Integer >(::fwDataTools::fieldHelper::Image::m_axialSliceIndexId)->getValue();
-        const auto frontalIndex =
-            image->getField< ::fwData::Integer >(::fwDataTools::fieldHelper::Image::m_frontalSliceIndexId)->getValue();
-        const auto sagittalIndex =
-            image->getField< ::fwData::Integer >(::fwDataTools::fieldHelper::Image::m_sagittalSliceIndexId)->getValue();
+        const auto imgSize       = image->getSize2();
+        const auto axialIdxField = image->getField< ::fwData::Integer >(
+            ::fwDataTools::fieldHelper::Image::m_axialSliceIndexId);
+        SLM_INFO_IF("Axial Idx field missing", !axialIdxField);
+        const auto axialIdx = axialIdxField ? axialIdxField->getValue() : static_cast<int>(imgSize[2]/2);
+
+        const auto frontalIdxField = image->getField< ::fwData::Integer >(
+            ::fwDataTools::fieldHelper::Image::m_frontalSliceIndexId);
+        SLM_INFO_IF("Frontal Idx field missing", !frontalIdxField);
+        const auto frontalIdx = frontalIdxField ? frontalIdxField->getValue() : static_cast<int>(imgSize[1]/2);
+
+        const auto sagittalIdxField = image->getField< ::fwData::Integer >(
+            ::fwDataTools::fieldHelper::Image::m_sagittalSliceIndexId);
+        SLM_INFO_IF("Sagittal Idx field missing", !sagittalIdxField);
+        const auto sagittalIdx = sagittalIdxField ? sagittalIdxField->getValue() : static_cast<int>(imgSize[0]/2);
 
         this->changeSliceIndex(
-            static_cast<int>(axialIndex),
-            static_cast<int>(frontalIndex),
-            static_cast<int>(sagittalIndex)
+            static_cast<int>(axialIdx),
+            static_cast<int>(frontalIdx),
+            static_cast<int>(sagittalIdx)
             );
     }
 
@@ -383,12 +392,19 @@ void SNegato3D::changeSliceIndex(int _axialIndex, int _frontalIndex, int _sagitt
     SLM_ASSERT("inout '" + s_IMAGE_INOUT + "' does not exist", image);
     const ::fwData::mt::ObjectReadLock imgLock(image);
 
-    const auto& imgSize = image->getSize2();
+    auto imgSize = image->getSize2();
+
+    // Sometimes, the image can contain only one slice,
+    // it results into a division by 0 when the range is transformed between [0-1].
+    // So we increase the image size to 2 to divide by 1.
+    imgSize[0] = imgSize[0] == 1 ? 2 : imgSize[0];
+    imgSize[1] = imgSize[1] == 1 ? 2 : imgSize[1];
+    imgSize[2] = imgSize[2] == 1 ? 2 : imgSize[2];
 
     const ::Ogre::Vector3 sliceIndices = {
-        static_cast<float>(_sagittalIndex ) / (static_cast<float>(imgSize[0] - 1)),
-        static_cast<float>(_frontalIndex  ) / (static_cast<float>(imgSize[1] - 1)),
-        static_cast<float>(_axialIndex    ) / (static_cast<float>(imgSize[2] - 1))
+        static_cast<float>(_sagittalIndex) / (static_cast<float>(imgSize[0] - 1)),
+        static_cast<float>(_frontalIndex) / (static_cast<float>(imgSize[1] - 1)),
+        static_cast<float>(_axialIndex) / (static_cast<float>(imgSize[2] - 1))
     };
 
     for (std::uint8_t i = 0; i < 3; ++i)
@@ -450,13 +466,13 @@ void SNegato3D::setPlanesOpacity()
 
 //------------------------------------------------------------------------------
 
-void SNegato3D::setVisibility(bool _visibility)
+void SNegato3D::setVisible(bool _visible)
 {
     const ::fwData::Image::sptr image = this->getInOut< ::fwData::Image >(s_IMAGE_INOUT);
     SLM_ASSERT("inout '" + s_IMAGE_INOUT + "' does not exist", image);
     const ::fwData::mt::ObjectReadLock imageLock(image);
 
-    image->setField(s_VISIBILITY_FIELD, ::fwData::Boolean::New(_visibility));
+    image->setField(s_VISIBILITY_FIELD, ::fwData::Boolean::New(_visible));
 
     this->setPlanesOpacity();
 
@@ -464,13 +480,21 @@ void SNegato3D::setVisibility(bool _visibility)
     auto visUpdateSig = image->signal<VisModSigType>( ::fwData::Image::s_VISIBILITY_MODIFIED_SIG );
 
     {
-        ::fwCom::Connection::Blocker(visUpdateSig->getConnection(this->slot(s_UPDATE_VISIBILITY_SLOT)));
-        visUpdateSig->asyncEmit(_visibility);
+        const ::fwCom::Connection::Blocker blocker(visUpdateSig->getConnection(this->slot(s_UPDATE_VISIBILITY_SLOT)));
+        visUpdateSig->asyncEmit(_visible);
     }
 }
 
 //------------------------------------------------------------------------------
 
+void SNegato3D::setVisibilityDeprecatedSlot(bool _visible)
+{
+    FW_DEPRECATED_MSG("::visuOgreAdaptor::SNegato3D::setVisibility is no longer supported", "21.0")
+    ::fwRenderOgre::IAdaptor::updateVisibility(_visible);
+}
+
+//------------------------------------------------------------------------------
+
 void SNegato3D::setPlanesQueryFlags(std::uint32_t _flags)
 {
     for(const auto& p : m_planes)
