@@ -63,7 +63,6 @@ static const ::fwCom::Slots::SlotKeyType s_TOGGLE_WIDGETS_SLOT       = "toggleWi
 static const ::fwCom::Slots::SlotKeyType s_SET_BOOL_PARAMETER_SLOT   = "setBoolParameter";
 static const ::fwCom::Slots::SlotKeyType s_SET_INT_PARAMETER_SLOT    = "setIntParameter";
 static const ::fwCom::Slots::SlotKeyType s_SET_DOUBLE_PARAMETER_SLOT = "setDoubleParameter";
-static const ::fwCom::Slots::SlotKeyType s_UPDATE_VISIBILITY_SLOT    = "updateVisibility";
 static const ::fwCom::Slots::SlotKeyType s_UPDATE_CLIPPING_BOX_SLOT  = "updateClippingBox";
 
 static const ::fwServices::IService::KeyType s_IMAGE_INOUT           = "image";
@@ -75,6 +74,7 @@ static const std::string s_PREINTEGRATION_CONFIG        = "preintegration";
 static const std::string s_DYNAMIC_CONFIG               = "dynamic";
 static const std::string s_WIDGETS_CONFIG               = "widgets";
 static const std::string s_PRIORITY_CONFIG              = "priority";
+static const std::string s_LAYER_ORDER_DEPENDANT_CONFIG = "layerOrderDependant";
 static const std::string s_SAMPLES_CONFIG               = "samples";
 static const std::string s_SAT_SIZE_RATIO_CONFIG        = "satSizeRatio";
 static const std::string s_SAT_SHELLS_CONFIG            = "satShells";
@@ -100,7 +100,6 @@ SVolumeRender::SVolumeRender() noexcept :
     newSlot(s_SET_BOOL_PARAMETER_SLOT, &SVolumeRender::setBoolParameter, this);
     newSlot(s_SET_INT_PARAMETER_SLOT, &SVolumeRender::setIntParameter, this);
     newSlot(s_SET_DOUBLE_PARAMETER_SLOT, &SVolumeRender::setDoubleParameter, this);
-    newSlot(s_UPDATE_VISIBILITY_SLOT, &SVolumeRender::updateVisibility, this);
     newSlot(s_UPDATE_CLIPPING_BOX_SLOT, &SVolumeRender::updateClippingBox, this);
 }
 
@@ -138,6 +137,7 @@ void SVolumeRender::configuring()
     m_dynamic                = config.get<bool>(s_DYNAMIC_CONFIG, m_dynamic);
     m_widgetVisibilty        = config.get<std::string>(s_WIDGETS_CONFIG, "yes") == "yes";
     m_priority               = config.get<int>(s_PRIORITY_CONFIG, m_priority);
+    m_layerOrderDependant    = config.get<bool>(s_LAYER_ORDER_DEPENDANT_CONFIG, m_layerOrderDependant);
     m_nbSamples              = config.get<std::uint16_t>(s_SAMPLES_CONFIG, m_nbSamples);
 
     // Advanced illumination parameters.
@@ -178,7 +178,6 @@ void SVolumeRender::starting()
     ::Ogre::SceneNode* rootSceneNode = m_sceneManager->getRootSceneNode();
     ::Ogre::SceneNode* transformNode = this->getTransformNode(rootSceneNode);
     m_volumeSceneNode                = transformNode->createChildSceneNode(this->getID() + "_transform_origin");
-    m_volumeSceneNode->setVisible(true, false);
 
     m_camera = this->getLayer()->getDefaultCamera();
 
@@ -211,6 +210,8 @@ void SVolumeRender::starting()
                                                                         m_ambientOcclusion,
                                                                         m_colorBleeding);
 
+    m_volumeSceneNode->setVisible(m_isVisible);
+
     // Initially focus on the image center.
     this->setFocalDistance(50);
 
@@ -467,7 +468,7 @@ void SVolumeRender::updateSampling(int _nbSamples)
 {
     this->getRenderService()->makeCurrent();
 
-    OSLM_ASSERT("Sampling rate must fit in a 16 bit uint.", _nbSamples < 65536 && _nbSamples >= 0);
+    SLM_ASSERT("Sampling rate must fit in a 16 bit uint.", _nbSamples < 65536 && _nbSamples >= 0);
     m_nbSamples = static_cast<std::uint16_t>(_nbSamples);
 
     m_volumeRenderer->setSampling(m_nbSamples);
@@ -804,7 +805,7 @@ void SVolumeRender::createWidget()
     const ::fwRenderOgre::Layer::sptr layer = this->getLayer();
 
     this->destroyWidget(); // Destroys the old widgets if they were created.
-    m_widget = std::make_shared< ::fwRenderOgre::interactor::ClippingBoxInteractor>(layer,
+    m_widget = std::make_shared< ::fwRenderOgre::interactor::ClippingBoxInteractor>(layer, m_layerOrderDependant,
                                                                                     this->getID(), m_volumeSceneNode,
                                                                                     ogreClippingMx, clippingMxUpdate,
                                                                                     "BasicAmbient", "BasicPhong");
@@ -939,7 +940,7 @@ void SVolumeRender::updateClippingTM3D()
         const auto sig =
             clippingMatrix->signal< ::fwData::Object::ModifiedSignalType >(::fwData::Object::s_MODIFIED_SIG);
 
-        ::fwCom::Connection::Blocker block(sig->getConnection(this->slot(s_UPDATE_CLIPPING_BOX_SLOT)));
+        ::fwCom::Connection::Blocker blocker(sig->getConnection(this->slot(s_UPDATE_CLIPPING_BOX_SLOT)));
 
         sig->asyncEmit();
     }
@@ -952,15 +953,15 @@ void SVolumeRender::updateClippingTM3D()
 
 //-----------------------------------------------------------------------------
 
-void SVolumeRender::updateVisibility(bool _visibility)
+void SVolumeRender::setVisible(bool _visible)
 {
     if(m_volumeSceneNode)
     {
-        m_volumeSceneNode->setVisible(_visibility);
+        m_volumeSceneNode->setVisible(_visible);
 
         if(m_widget)
         {
-            m_widget->setBoxVisibility(_visibility && m_widgetVisibilty);
+            m_widget->setBoxVisibility(_visible && m_widgetVisibilty);
         }
 
         this->requestRender();
