@@ -115,7 +115,6 @@ public:
 
     void startSlicing()
     {
-        SLM_TRACE("vtkEvent: MiddleButtonPressEvent");
         SLM_ASSERT("m_adaptor not instanced", m_adaptor);
         SLM_ASSERT("m_picker not instanced", m_picker);
 
@@ -128,13 +127,8 @@ public:
         pickPoint[1] = y;
         pickPoint[2] = 0;
 
-        OSLM_TRACE(
-            "vtkEvent: MiddleButtonPressEvent: picking " << pickPoint[0] << ", " << pickPoint[1] << ", " <<
-                pickPoint[2]);
-
         if ( this->Pick(pickPoint, pickedPoint) )
         {
-            SLM_TRACE("vtkEvent: MiddleButtonPressEvent:picked point");
             SLM_ASSERT("Slicing has already begun", !m_mouseMoveObserved);
             m_adaptor->getInteractor()->AddObserver(vtkCommand::MouseMoveEvent, this, 1.);
             m_mouseMoveObserved = true;
@@ -158,7 +152,6 @@ public:
 
     void stopSlicing()
     {
-        SLM_TRACE("vtkEvent: MiddleButtonReleaseEvent");
         SLM_ASSERT("m_adaptor not instanced", m_adaptor);
         SLM_ASSERT("m_picker not instanced", m_picker);
         SLM_ASSERT("Slicing doesn't begun", m_mouseMoveObserved);
@@ -193,7 +186,6 @@ public:
             }
             else if (eventId == vtkCommand::MouseMoveEvent)
             {
-                SLM_TRACE("vtkEvent: MouseMoveEvent");
                 SLM_ASSERT("m_mouseMoveObserved not instanced", m_mouseMoveObserved);
 
                 int x, y;
@@ -477,16 +469,12 @@ void SNegatoSlicingInteractor::updateSlicing( double pickedPoint[3] )
     this->worldToImageSliceIndex(pickedPoint, index);
     index[m_orientation] = originalIndex;
 
-    OSLM_TRACE("sliceIndex[0] "<< sliceIndex[0]->value()<< " index[0] " << index[0] << " pickedPt "<<pickedPoint[0]);
-    OSLM_TRACE("sliceIndex[1] "<< sliceIndex[1]->value()<< " index[1] " << index[1] << " pickedPt "<<pickedPoint[1]);
-    OSLM_TRACE("sliceIndex[2] "<< sliceIndex[2]->value()<< " index[2] " << index[2] << " pickedPt "<<pickedPoint[2]);
-
 #ifdef DEBUG
     for ( int i = 0; i < image->getNumberOfDimensions(); i++ )
     {
-        OSLM_ASSERT("index["<< i <<"] = " << index[i]
-                            << " and image->getSize()[" << i << "] = " << image->getSize2()[i],
-                    index[i] >= 0 && index[i] < image->getSize2()[i]);
+        SLM_ASSERT("index["<< i <<"] = " << index[i]
+                           << " and image->getSize()[" << i << "] = " << image->getSize2()[i],
+                   index[i] >= 0 && index[i] < image->getSize2()[i]);
     }
 #endif
 
